@@ -129,12 +129,12 @@ impl fmt::Debug for ColorSpace {
 }
 
 impl ColorSpace {
-    pub fn new_srgb() -> ColorSpace {
-        ColorSpace::from_ptr(unsafe { sb::C_SkColorSpace_MakeSRGB() }).unwrap()
+    pub fn new_srgb() -> Self {
+        Self::from_ptr(unsafe { sb::C_SkColorSpace_MakeSRGB() }).unwrap()
     }
 
-    pub fn new_srgb_linear() -> ColorSpace {
-        ColorSpace::from_ptr(unsafe { sb::C_SkColorSpace_MakeSRGBLinear() }).unwrap()
+    pub fn new_srgb_linear() -> Self {
+        Self::from_ptr(unsafe { sb::C_SkColorSpace_MakeSRGBLinear() }).unwrap()
     }
 
     pub fn to_xyzd50_hash(&self) -> XYZD50Hash {
@@ -142,17 +142,18 @@ impl ColorSpace {
     }
 
     #[must_use]
-    pub fn with_linear_gamma(&self) -> ColorSpace {
-        ColorSpace::from_ptr(unsafe { sb::C_SkColorSpace_makeLinearGamma(self.native()) }).unwrap()
+    pub fn with_linear_gamma(&self) -> Self {
+        Self::from_ptr(unsafe { sb::C_SkColorSpace_makeLinearGamma(self.native()) }).unwrap()
     }
 
     #[must_use]
-    pub fn with_srgb_gamma(&self) -> ColorSpace {
-        ColorSpace::from_ptr(unsafe { sb::C_SkColorSpace_makeSRGBGamma(self.native()) }).unwrap()
+    pub fn with_srgb_gamma(&self) -> Self {
+        Self::from_ptr(unsafe { sb::C_SkColorSpace_makeSRGBGamma(self.native()) }).unwrap()
     }
 
-    pub fn with_color_spin(&self) -> ColorSpace {
-        ColorSpace::from_ptr(unsafe { sb::C_SkColorSpace_makeColorSpin(self.native()) }).unwrap()
+    #[must_use]
+    pub fn with_color_spin(&self) -> Self {
+        Self::from_ptr(unsafe { sb::C_SkColorSpace_makeColorSpin(self.native()) }).unwrap()
     }
 
     pub fn is_srgb(&self) -> bool {
@@ -165,13 +166,11 @@ impl ColorSpace {
 
     // TODO: writeToMemory()?
 
-    pub fn deserialize(data: impl Into<Data>) -> ColorSpace {
+    pub fn deserialize(data: impl Into<Data>) -> Self {
         let data = data.into();
         let bytes = data.as_bytes();
-        ColorSpace::from_ptr(unsafe {
-            sb::C_SkColorSpace_Deserialize(bytes.as_ptr() as _, bytes.len())
-        })
-        .unwrap()
+        Self::from_ptr(unsafe { sb::C_SkColorSpace_Deserialize(bytes.as_ptr() as _, bytes.len()) })
+            .unwrap()
     }
 
     // TODO: transferFn()
