@@ -1,70 +1,6 @@
-use crate::{prelude::*, scalar, Matrix, NativeFlattenable, Path, Point, Rect, StrokeRec, Vector};
-use skia_bindings::{
-    self as sb, SkFlattenable, SkPathEffect, SkPathEffect_DashType, SkPathEffect_PointData,
-    SkRefCntBase,
-};
-use std::{fmt, os::raw};
-
-#[repr(C)]
-#[derive(Debug)]
-pub struct PointData {
-    pub flags: point_data::PointFlags,
-    points: *const Point,
-    num_points: raw::c_int,
-    pub size: Vector,
-    pub clip_rect: Rect,
-    pub path: Path,
-    pub first: Path,
-    pub last: Path,
-}
-
-unsafe_send_sync!(PointData);
-
-native_transmutable!(SkPathEffect_PointData, PointData, point_data_layout);
-
-#[test]
-fn test_point_data_fields_layout() {
-    Point::test_layout();
-    Vector::test_layout();
-    Rect::test_layout();
-}
-
-impl Drop for PointData {
-    fn drop(&mut self) {
-        unsafe {
-            // we can't call destruct, because it would destruct
-            // other fields like Path, which would also be dropped individually,
-            // so we just delete the points array here.
-            sb::C_SkPathEffect_PointData_deletePoints(self.native_mut())
-        }
-    }
-}
-
-impl Default for PointData {
-    fn default() -> Self {
-        PointData::construct(|point_data| unsafe {
-            sb::C_SkPathEffect_PointData_Construct(point_data)
-        })
-    }
-}
-
-impl PointData {
-    pub fn points(&self) -> &[Point] {
-        unsafe { safer::from_raw_parts(self.points, self.num_points.try_into().unwrap()) }
-    }
-}
-
-pub mod point_data {
-    use skia_bindings as sb;
-
-    bitflags! {
-        pub struct PointFlags: u32 {
-            const CIRCLES = sb::SkPathEffect_PointData_PointFlags_kCircles_PointFlag as _;
-            const USE_PATH = sb::SkPathEffect_PointData_PointFlags_kUsePath_PointFlag as _;
-            const USE_CLIP = sb::SkPathEffect_PointData_PointFlags_kUseClip_PointFlag as _;
-        }
-    }
-}
+use crate::{prelude::*, scalar, Matrix, NativeFlattenable, Path, Rect, StrokeRec};
+use skia_bindings::{self as sb, SkFlattenable, SkPathEffect, SkPathEffect_DashType, SkRefCntBase};
+use std::fmt;
 
 #[derive(Clone, PartialEq, Debug)]
 pub struct DashInfo {
@@ -96,6 +32,7 @@ impl fmt::Debug for PathEffect {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         f.debug_struct("PathEffect")
             .field("as_a_dash", &self.as_a_dash())
+            .field("needs_ctm", &self.needs_ctm())
             .finish()
     }
 }
@@ -115,6 +52,28 @@ impl PathEffect {
         .unwrap()
     }
 
+    // TODO: rename to to_a_dash()?
+    pub fn as_a_dash(&self) -> Option<DashInfo> {
+        let mut dash_info = construct(|di| unsafe { sb::C_SkPathEffect_DashInfo_Construct(di) });
+
+        let dash_type = unsafe { self.native().asADash(&mut dash_info) };
+
+        match dash_type {
+            SkPathEffect_DashType::kDash_DashType => {
+                let mut v: Vec<scalar> = vec![0.0; dash_info.fCount.try_into().unwrap()];
+                dash_info.fIntervals = v.as_mut_ptr();
+                unsafe {
+                    assert_eq!(dash_type, self.native().asADash(&mut dash_info));
+                }
+                Some(DashInfo {
+                    intervals: v,
+                    phase: dash_info.fPhase,
+                })
+            }
+            SkPathEffect_DashType::kNone_DashType => None,
+        }
+    }
+
     pub fn filter_path(
         &self,
         src: &Path,
@@ -144,52 +103,26 @@ impl PathEffect {
         }
     }
 
-    // TODO: rename to to_points()?
-    pub fn as_points(
+    pub fn filter_path_inplace_with_matrix(
         &self,
+        dst: &mut Path,
         src: &Path,
-        stroke_rect: &StrokeRec,
-        matrix: &Matrix,
+        stroke_rec: &mut StrokeRec,
         cull_rect: impl AsRef<Rect>,
-    ) -> Option<PointData> {
-        let mut point_data = PointData::default();
+        ctm: &Matrix,
+    ) -> bool {
         unsafe {
-            self.native().asPoints(
-                point_data.native_mut(),
+            self.native().filterPath1(
+                dst.native_mut(),
                 src.native(),
-                stroke_rect.native(),
-                matrix.native(),
+                stroke_rec.native_mut(),
                 cull_rect.as_ref().native(),
+                ctm.native(),
             )
         }
-        .if_true_some(point_data)
     }
 
-    // TODO: rename to to_a_dash()?
-    pub fn as_a_dash(&self) -> Option<DashInfo> {
-        let mut dash_info = construct(|di| unsafe { sb::C_SkPathEffect_DashInfo_Construct(di) });
-
-        let dash_type = unsafe { self.native().asADash(&mut dash_info) };
-
-        match dash_type {
-            SkPathEffect_DashType::kDash_DashType => {
-                let mut v: Vec<scalar> = vec![0.0; dash_info.fCount.try_into().unwrap()];
-                dash_info.fIntervals = v.as_mut_ptr();
-                unsafe {
-                    assert_eq!(dash_type, self.native().asADash(&mut dash_info));
-                }
-                Some(DashInfo {
-                    intervals: v,
-                    phase: dash_info.fPhase,
-                })
-            }
-            SkPathEffect_DashType::kNone_DashType => None,
-        }
+    pub fn needs_ctm(&self) -> bool {
+        unsafe { self.native().needsCTM() }
     }
 }
-
-#[test]
-fn create_and_drop_point_data() {
-    let data = PointData::default();
-    drop(data)
-}
